#!/usr/bin/env bash
###
 # Script to setup Linux after a fresh install.
 ##


# Abort on error
set -e


# Import utility script.
source $(dirname ${0})/src/utils.sh


###
 # Program main.
 ##
function main () {
    run_script_loop=true

    # Make sure user is not root user.
    check_is_not_user root

    # Provide program summary help.
    echo ""
    echo -e "${text_blue}This script provides some quick and easy setup functions for a linux install.${text_reset}"
    echo -e "${text_blue}For example, it can map all the \"standard\" user folders to an external drive,${text_reset}"
    echo -e "${text_blue}or install the latest version of some very common software.${text_reset}"
    echo -e "${text_blue}May not work with all versions of linux.${text_reset}"
    echo ""

    # Run program loop.
    while [[ $run_script_loop == true ]]
    do
        # Display options.
        echo ""
        echo -e "${text_blue}Select an option:${text_reset}"
        echo -e "${text_cyan}1${text_reset}) Initialize Git (Git required for some other options)"
        echo -e "${text_cyan}2${text_reset}) Setup Local Database"
        echo -e "${text_cyan}3${text_reset}) Setup Python for Development"
        echo -e "${text_cyan}4${text_reset}) Install/Update Npm & NodeJs"
        echo -e "${text_cyan}0${text_reset}) Exit"

        # Get user input.
        read user_input

        # Handle based on selected option.
        if [[ "${user_input}" == "1" ]]
        then
            # Git initialization.
            ./initialize_git.sh

        elif [[ "${user_input}" == "2" ]]
        then
            # Setup local database.
            echo ""
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            get_user_confirmation "${text_blue}This will also trigger a general system update. Is this okay?${text_reset}"

            if [[ ${return_value} == true ]]
            then
                # Check if dir exists. Purge if so.
                if [[ -d "./database_setup" ]]
                then
                    sudo rm -r ./database_setup
                fi

                # Clone relevant script to local machine.
                git clone https://git.brandon-rodriguez.com/scripts/bash/database_setup.git
                cd ./database_setup/
                ./run.sh
                cd ..

                echo ""
                echo -e "${text_blue}Local database installed and setup."
                echo ""

            else
                echo ""
                echo -e "${text_blue}Cancelling local database setup."
                echo ""
            fi

        elif [[ "${user_input}" == "3" ]]
        then
            # Setup Python for development.
            echo ""
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            get_user_confirmation "${text_blue}This will also add the Python deadsnakes/ppa and add minor Python-environment functionality to the cd function. Is this okay?${text_reset}"

            if [[ ${return_value} == true ]]
            then
                ./setup_python_for_development.sh
            else
                echo ""
                echo -e "${text_blue}Cancelling Python development setup."
                echo ""
            fi


        elif [[ "${user_input}" == "4" ]]
        then
            # Install/Update Npm & NodeJs.
            echo ""
            echo -e "${text_blue}Sudo is required for installing/updating system files.${text_reset}"
            echo -e "${text_blue}This may ask for your system password.${text_reset}"
            get_user_confirmation "${text_blue}This will also trigger a general system update. Is this okay?${text_reset}"

            if [[ ${return_value} == true ]]
            then
                sudo ./setup_npm.sh
            else
                echo ""
                echo -e "${text_blue}Cancelling Npm/NodeJs setup."
                echo ""
            fi

        elif [[ "${user_input}" == "0" ]]
        then
            # Exit program.
            echo ""
            echo -e "${text_blue}Exiting program.${text_reset}"
            run_script_loop=false

        else
            # Handle unrecognized input.
            echo ""
            echo -e "${text_red}Unrecognized selection.${text_reset}"
            echo ""
        fi



    done

    echo -e "${text_blue}Terminating script.${text_reset}"

}


main
